    PROGRAM TEST1
    IMPLICIT REAL*8 (A-H,O-Z)	
	PARAMETER(N=11)
	DIMENSION X(N),Y0(N),Y(N),YNEWTON(N),V(N),Fk(N),Gk(N),Uk(N),AV(N),BV(N),DY(N),D2Y(N)   

    !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    !!!                                                                              !!!
    !!!                      B.BATGEREL, E.V.ZEMLYANAYA, I.V.PUZYNIN                 !!!
    !!!                                                                              !!!
    !!!      PRGORAMMA NINE FOR NUMERICAL SOLUTION OF THE BOUNDARY PROBLEMS FOR      !!!
    !!!            NONLINEAR DIFFERENTIAL EQUATIONS ON THE BASIS OF CANM             !!!
    !!!                                                                              !!!
    !!!                           y" + f(x,y,y') = 0,  a < x < b,                    !!!
    !!!                                                                              !!!
    !!!                           alpha1*y'(a)+beta1*y(a) = gamma1,                  !!!
    !!!                                                                              !!!
    !!!                           alpha2*y'(b)+beta2*y(b) = gamma2.                  !!!
    !!!                                                                              !!!
    !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

    !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    !!!                                                                              !!!
    !!!        TEST1:             y"-(y'/x)^2 = 0,                                   !!!
    !!!                                                                              !!!
    !!!                           y(2)  = -1,                                        !!!
    !!!                           y'(3) = -3/2.                                      !!!
    !!!                                                                              !!!
    !!!        SOLUTION:          y(x)=1-x-ln|x-1|                                   !!!
    !!!                                                                              !!!
    !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

    !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    !!!                                                                              !!!
    !!!    THE RESULTS WILL BE WRITTEN IN THE FILES 'ITERATIONS' AND 'SOLUTION'      !!! 
    !!!                                                                              !!!
    !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

    A=2D0;         B=3D0;                                     !  INTERVAL OF INTEGRATION
    
    ALPHA1=0D0;    BETA1=1D0;    GAMMA1=-1D0                  !  BOUNDARY CONDITION ON x=A  
    ALPHA2=1D0;    BETA2=0D0;    GAMMA2=-1.5D0                !  BOUNDARY CONDITION ON x=B   
    
    H=(B-A)/(N-1)                                             !  STEP OF INTEGRATION    
    TOL=1D-6                                                  !  TOLERANCE
	
	DO I=1,N
	   X(I)=A+(I-1)*H
       Y0(I)=1D0-X(I)-DLOG(DABS(X(I)-1D0))                    ! EXACT SOLUTION
       Y(I)=2D0*Y0(I)-0.1D0                                   ! INITIAL GUESS
    ENDDO
    
    KEY_TAU=1                                                 ! KEY FOR TAU = {1,2,3,4,5}
    TAUMIN=0.1D0                                              ! LOWER BOUND OF TAU0
    ITER_MAX=100                                              ! MAXIMAL NUMBER OF ITERATIONS
        
    CALL NINE(N,H,TOL,ALPHA1,ALPHA2,BETA1,BETA2,GAMMA1,GAMMA2,KEY_TAU,TAUMIN,ITER_MAX,X,&
              YNEWTON,V,Fk,Gk,Uk,AV,BV,DY,D2Y,Y)
    
    OPEN(1,FILE='TEST1')
    DO I=1,N
       WRITE(1,*) X(I),Y(I)-Y0(I)
    ENDDO

    END

   	REAL*8 FUNCTION FF(X,Y,Z)                                 ! f(x,y,y')
	IMPLICIT REAL*8 (A-H,O-Z)
    	FF=-(Z/X)**2
	RETURN
	END
    
	REAL*8 FUNCTION FY(X,Y,Z)                                 ! df(x,y,y')/dy
	IMPLICIT REAL*8 (A-H,O-Z)
		FY=0D0
	RETURN
	END
	   
    REAL*8 FUNCTION FDY(X,Y,Z)                                ! df(x,y,y')/dy'
	IMPLICIT REAL*8 (A-H,O-Z)
		FDY=-2D0*Z/X**2
	RETURN
	END   